=======================================
``psyclone.tests.gen_kernel_stub_test``
=======================================

.. automodule:: psyclone.tests.gen_kernel_stub_test

   .. contents::
      :local:

.. currentmodule:: psyclone.tests.gen_kernel_stub_test
